@@ -71,7 +71,7 @@
 #'       Coming soon.
 #'     }
 #'     \item{\code{serialize_to_crul}}{
-#'       Serialize interaction on disk/casette to a \code{crul} response
+#'       Serialize interaction on disk/cassette to a \code{crul} response
 #'     }
 #'   }
 #' @format NULL
@@ -140,7 +140,7 @@ Cassette <- R6::R6Class(
       self$serialize_with <- serialize_with
       self$persist_with <- persist_with
       if (!missing(record)) {
-        recmodes <- c('none', 'once', 'new_episodes', 'all')
+        recmodes <- c("none", "once", "new_episodes", "all")
         if (!record %in% recmodes) {
           stop("'record' value of '", record, "' is not in the allowed set: ",
                paste0(recmodes, collapse = ", "), call. = FALSE)
@@ -211,15 +211,20 @@ Cassette <- R6::R6Class(
           m <- self$match_requests_on
           if (all(m %in% c("method", "uri")) && length(m) == 2) {
             webmockr::stub_request(req$method, req$uri)
-          } else if (all(m %in% c("method", "uri", "query")) && length(m) == 3) {
+          } else if (
+            all(m %in% c("method", "uri", "query")) && length(m) == 3) {
             tmp <- webmockr::stub_request(req$method, req$uri)
             webmockr::wi_th(tmp, .list = list(query = uripp$parameter))
-          } else if (all(m %in% c("method", "uri", "headers")) && length(m) == 3) {
+          } else if (
+            all(m %in% c("method", "uri", "headers")) && length(m) == 3) {
             tmp <- webmockr::stub_request(req$method, req$uri)
             webmockr::wi_th(tmp, .list = list(query = req$headers))
-          } else if (all(m %in% c("method", "uri", "headers", "query")) && length(m) == 4) {
+          } else if (
+            all(m %in% c("method", "uri", "headers", "query")) &&
+            length(m) == 4) {
             tmp <- webmockr::stub_request(req$method, req$uri)
-            webmockr::wi_th(tmp, .list = list(query = uripp$parameter, headers = req$headers))
+            webmockr::wi_th(tmp, .list = list(query = uripp$parameter,
+              headers = req$headers))
           }
         }))
       }
@@ -234,12 +239,15 @@ Cassette <- R6::R6Class(
         self$allow_playback_repeats,
         self$preserve_exact_body_bytes
       )
-      init_opts <- compact(stats::setNames(tmp, c("name", "record", "serialize_with",
+      init_opts <- compact(
+        stats::setNames(tmp, c("name", "record", "serialize_with",
         "persist_with", "match_requests_on", "update_content_length_header",
         "allow_playback_repeats", "preserve_exact_body_bytes")))
       self$cassette_opts <- init_opts
-      init_opts <- paste(names(init_opts), unname(init_opts), sep=": ", collapse=", ")
-      vcr_log_info(sprintf("Initialized with options: {%s}", init_opts), vcr_c$log_opts$date)
+      init_opts <- paste(names(init_opts), unname(init_opts), sep = ": ",
+        collapse = ", ")
+      vcr_log_info(sprintf("Initialized with options: {%s}", init_opts),
+        vcr_c$log_opts$date)
 
       # create new env for recorded interactions
       self$new_recorded_interactions <- list()
@@ -278,10 +286,6 @@ Cassette <- R6::R6Class(
       }
       # allow http interactions - disallow at end of call_block() below
       webmockr::webmockr_allow_net_connect()
-      
-      # FIXME: temporary attempt to make it work: turn on mocking for httr
-      webmockr::httr_mock()
-      
       # evaluate request
       resp <- lazyeval::lazy_eval(tmp)
       # disallow http interactions - allow at start of call_block() above
@@ -358,9 +362,11 @@ Cassette <- R6::R6Class(
                                   self$match_requests_on)
         old_interactions <-
           Filter(function(x) {
-            req <- Request$new()$from_hash(x$request)
-            new_interaction_list$response_for(req)
-          }, old_interactions)
+              req <- Request$new()$from_hash(x$request)
+              !unlist(new_interaction_list$has_interaction_matching(req))
+            },
+            old_interactions
+          )
       }
 
       # FIXME: add up_to_date_interactions usage here
@@ -369,7 +375,8 @@ Cassette <- R6::R6Class(
 
     # FIXME: not used yet, from newer version of vcr
     up_to_date_interactions = function(interactions) {
-      if (self$clean_outdated_http_interactions &&
+      if (
+        self$clean_outdated_http_interactions &&
         !is.null(re_record_interval)
       ) {
         return(interactions)
@@ -379,7 +386,13 @@ Cassette <- R6::R6Class(
       }, interactions)
     },
 
-    should_remove_matching_existing_interactions = function() self$record == "all",
+    should_stub_requests = function() {
+      self$record != "all"
+    },
+
+    should_remove_matching_existing_interactions = function() {
+      self$record == "all"
+    },
     storage_key = function() self$serializer$path,
 
     raw_cassette_bytes = function() {
@@ -405,14 +418,17 @@ Cassette <- R6::R6Class(
 
     previously_recorded_interactions = function() {
       if (nchar(self$raw_cassette_bytes()) > 0) {
-        tmp <- compact(lapply(self$deserialized_hash()[['http_interactions']], function(z) {
+        tmp <- compact(
+          lapply(self$deserialized_hash()[["http_interactions"]], function(z) {
           response <- VcrResponse$new(
-            z$response$status$status_code,
+            # z$response$status$status_code,
+            z$response$status,
             z$response$headers,
             z$response$body$string,
             self$cassette_opts
           )
-          if (self$update_content_length_header) response$update_content_length_header()
+          if (self$update_content_length_header) 
+            response$update_content_length_header()
           zz <- HTTPInteraction$new(
             request = Request$new(z$request$method,
                                   z$request$uri,
@@ -479,7 +495,13 @@ Cassette <- R6::R6Class(
 
     http_interactions = function() {
       self$http_interactions_ <- HTTPInteractionList$new(
-        interactions = self$previously_recorded_interactions(),
+        interactions = {
+          if (self$should_stub_requests()) {
+            self$previously_recorded_interactions()
+          } else {
+            list()
+          }
+        },
         request_matchers = vcr_configuration()$match_requests_on
       )
     },
@@ -494,17 +516,26 @@ Cassette <- R6::R6Class(
         } else {
           x$request$fields
         },
-        if (inherits(x, "response")) as.list(x$request$headers) else x$request_headers,
+        if (inherits(x, "response")) {
+          as.list(x$request$headers)
+        } else {
+          x$request_headers
+        },
         self$cassette_opts
       )
       response <- VcrResponse$new(
-        if (inherits(x, "response")) httr::http_status(x) else unclass(x$status_http()),
+        if (inherits(x, "response")) {
+          c(list(status_code = x$status_code), httr::http_status(x))
+        } else unclass(x$status_http()),
         if (inherits(x, "response")) x$headers else x$response_headers,
         rawToChar(x$content),
-        if (inherits(x, "response")) x$all_headers[[1]]$version else x$response_headers$status,
+        if (inherits(x, "response")) {
+          x$all_headers[[1]]$version
+        } else x$response_headers$status,
         self$cassette_opts
       )
-      if (self$update_content_length_header) response$update_content_length_header()
+      if (self$update_content_length_header)
+        response$update_content_length_header()
       HTTPInteraction$new(request = request, response = response)
     },
 
